@@ -1,6 +1,6 @@
-require 'nokogiri/version'
+require 'nokogiri'
 
-rspec_rails_repo_path = File.expand_path("../../", __FILE__)
+rspec_rails_repo_path = File.expand_path('..', __dir__)
 rspec_dependencies_gemfile = File.join(rspec_rails_repo_path, 'Gemfile-rspec-dependencies')
 rails_dependencies_gemfile = File.join(rspec_rails_repo_path, 'Gemfile-rails-dependencies')
 bundle_install_path = File.join(rspec_rails_repo_path, '..', 'bundle')
@@ -23,39 +23,46 @@ in_root do
   gsub_file "Gemfile", /.*debugger.*/, ''
   gsub_file "Gemfile", /.*byebug.*/, "gem 'byebug', '~> 9.0.6'"
   gsub_file "Gemfile", /.*puma.*/, ""
-  if RUBY_VERSION < '2.2.2'
-    gsub_file "Gemfile", /.*rdoc.*/, "gem 'rdoc', '< 6'"
-  end
+  gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.3.6'"
+  gsub_file "Gemfile", /.*bootsnap.*/, ""
 
   if Rails::VERSION::STRING >= '5.0.0'
-    append_to_file('Gemfile', "gem 'rails-controller-testing', :git => 'https://github.com/rails/rails-controller-testing'\n")
+    append_to_file('Gemfile', "gem 'rails-controller-testing'\n")
   end
 
-  if Rails::VERSION::STRING >= '5.2.0'
+  if Rails::VERSION::STRING >= '6'
+    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.4'"
+    gsub_file "Gemfile", /.*rails-controller-testing.*/, "gem 'rails-controller-testing', git: 'https://github.com/rails/rails-controller-testing'"
+  end
+
+  if Rails::VERSION::STRING >= "5.1.0"
+    if RUBY_VERSION < "2.3"
+      gsub_file "Gemfile", /.*capybara.*/, "gem 'capybara', '~> 3.1.0'"
+    elsif RUBY_VERSION < "2.4"
+      gsub_file "Gemfile", /.*capybara.*/, "gem 'capybara', '~> 3.15.0'"
+    end
+    if Rails::VERSION::STRING >= "5.2.0"
+      gsub_file "Gemfile", /.*chromedriver-helper.*/, "gem 'webdrivers', '< 4.0.0'"
+    else
+      gsub_file "Gemfile", /.*chromedriver-helper.*/, "gem 'webdrivers'"
+    end
+  end
+
+  if Rails::VERSION::STRING >= '5.2.0' && Rails::VERSION::STRING < '6'
     copy_file sqlite_initializer, 'config/initializers/sqlite3_fix.rb'
   end
 
   # Nokogiri version is pinned in rspec-rails' Gemfile since it tend to cause installation problems
   # on Travis CI, so we pin nokogiri in this example app also.
-  append_to_file 'Gemfile', "gem 'nokogiri', '#{Nokogiri::VERSION}'\n"
+  if RUBY_ENGINE != "jruby"
+    append_to_file 'Gemfile', "gem 'nokogiri', '#{Nokogiri::VERSION}'\n"
+  else
+    gsub_file "Gemfile", /.*jdbc.*/, ""
+  end
 
   # Use our version of RSpec and Rails
   append_to_file 'Gemfile', <<-EOT.gsub(/^ +\|/, '')
-    |# Rack::Cache 1.3.0 requires Ruby >= 2.0.0
-    |gem 'rack-cache', '< 1.3.0' if RUBY_VERSION < '2.0.0'
-    |
-    |if RUBY_VERSION >= '2.0.0'
-    |  gem 'rake', '>= 10.0.0'
-    |elsif RUBY_VERSION >= '1.9.3'
-    |  gem 'rake', '< 12.0.0' # rake 12 requires Ruby 2.0.0 or later
-    |else
-    |  gem 'rake', '< 11.0.0' # rake 11 requires Ruby 1.9.3 or later
-    |end
-    |
-    |# Version 3 of mime-types 3 requires Ruby 2.0
-    |if RUBY_VERSION < '2.0.0'
-    |  gem 'mime-types', '< 3'
-    |end
+    |gem 'rake', '>= 10.0.0'
     |
     |gem 'rspec-rails',
     |    :path => '#{rspec_rails_repo_path}',
