@@ -15,8 +15,7 @@ module RSpec
           SourceAnnotationExtractor::Annotation.register_directories("spec")
         end
       end
-      # Rails-3.0.1 requires config.app_generators instead of 3.0.0's config.generators
-      generators = config.respond_to?(:app_generators) ? config.app_generators : config.generators
+      generators = config.app_generators
       generators.integration_tool :rspec
       generators.test_framework :rspec
 
@@ -31,14 +30,15 @@ module RSpec
       # This is called after the environment has been loaded but before Rails
       # sets the default for the `preview_path`
       initializer "rspec_rails.action_mailer",
-                  :before => "action_mailer.set_configs" do |app|
-        setup_preview_path(app)
-      end
+                  before: "action_mailer.set_configs" do |app|
+                    setup_preview_path(app)
+                  end
 
     private
 
       def setup_preview_path(app)
         return unless supports_action_mailer_previews?(app.config)
+
         options = app.config.action_mailer
         config_default_preview_path(options) if config_preview_path?(options)
       end
@@ -46,9 +46,7 @@ module RSpec
       def config_preview_path?(options)
         # We cannot use `respond_to?(:show_previews)` here as it will always
         # return `true`.
-        if ::Rails::VERSION::STRING < '4.2'
-          ::Rails.env.development?
-        elsif options.show_previews.nil?
+        if options.show_previews.nil?
           options.show_previews = ::Rails.env.development?
         else
           options.show_previews
@@ -57,6 +55,7 @@ module RSpec
 
       def config_default_preview_path(options)
         return unless options.preview_path.blank?
+
         options.preview_path = "#{::Rails.root}/spec/mailers/previews"
       end
 
@@ -72,7 +71,7 @@ module RSpec
         # not respond to the method. However, we cannot use
         # `config.action_mailer.respond_to?(:preview_path)` here as it will
         # always return `true`.
-        config.respond_to?(:action_mailer) && ::Rails::VERSION::STRING > '4.1'
+        config.respond_to?(:action_mailer)
       end
     end
   end
