@@ -9,3 +9,5 @@ require 'rspec/rails/example/model_example_group'
 require 'rspec/rails/example/job_example_group'
 require 'rspec/rails/example/feature_example_group'
 require 'rspec/rails/example/system_example_group'
+require 'rspec/rails/example/channel_example_group'
+require 'rspec/rails/example/mailbox_example_group'
