@@ -15,7 +15,11 @@ module RSpec
       CHARS_TO_TRANSLATE = ['/', '.', ':', ',', "'", '"', " "].freeze
 
       # @private
-      module BlowAwayAfterTeardownHook
+      module BlowAwayTeardownHooks
+        # @private
+        def before_teardown
+        end
+
         # @private
         def after_teardown
         end
@@ -37,7 +41,7 @@ module RSpec
         @method_name ||= [
           self.class.name.underscore,
           RSpec.current_example.description.underscore
-        ].join("_").tr(CHARS_TO_TRANSLATE.join, "_")[0...251] + "_#{rand(1000)}"
+        ].join("_").tr(CHARS_TO_TRANSLATE.join, "_")[0...200] + "_#{rand(1000)}"
       end
 
       # Delegates to `Rails.application`.
@@ -46,28 +50,34 @@ module RSpec
       end
 
       included do |other|
+        ActiveSupport.on_load(:action_dispatch_system_test_case) do
+          ActionDispatch::SystemTesting::Server.silence_puma = true
+        end
+
         begin
           require 'capybara'
           require 'action_dispatch/system_test_case'
-        # rubocop:disable Lint/HandleExceptions
         rescue LoadError => e
-          # rubocop:enable Lint/HandleExceptions
           abort """
             LoadError: #{e.message}
             System test integration requires Rails >= 5.1 and has a hard
             dependency on a webserver and `capybara`, please add capybara to
             your Gemfile and configure a webserver (e.g. `Capybara.server =
-            :webrick`) before attempting to use system tests.
+            :webrick`) before attempting to use system specs.
           """.gsub(/\s+/, ' ').strip
         end
 
+        if ::Rails::VERSION::STRING >= '6.0'
+          original_before_teardown =
+            ::ActionDispatch::SystemTesting::TestHelpers::SetupAndTeardown.instance_method(:before_teardown)
+        end
+
         original_after_teardown =
           ::ActionDispatch::SystemTesting::TestHelpers::SetupAndTeardown.instance_method(:after_teardown)
 
-        other.include ActionDispatch::IntegrationTest::Behavior
         other.include ::ActionDispatch::SystemTesting::TestHelpers::SetupAndTeardown
         other.include ::ActionDispatch::SystemTesting::TestHelpers::ScreenshotHelper
-        other.include BlowAwayAfterTeardownHook
+        other.include BlowAwayTeardownHooks
 
         attr_reader :driver
 
@@ -78,16 +88,19 @@ module RSpec
         def initialize(*args, &blk)
           super(*args, &blk)
           @driver = nil
+
+          self.class.before do
+            # A user may have already set the driver, so only default if driver
+            # is not set
+            driven_by(:selenium) unless @driver
+          end
         end
 
-        def driven_by(*args, &blk)
-          @driver = ::ActionDispatch::SystemTestCase.driven_by(*args, &blk).tap(&:use)
+        def driven_by(driver, **driver_options, &blk)
+          @driver = ::ActionDispatch::SystemTestCase.driven_by(driver, **driver_options, &blk).tap(&:use)
         end
 
         before do
-          # A user may have already set the driver, so only default if driver
-          # is not set
-          driven_by(:selenium) unless @driver
           @routes = ::Rails.application.routes
         end
 
@@ -95,6 +108,9 @@ module RSpec
           orig_stdout = $stdout
           $stdout = StringIO.new
           begin
+            if ::Rails::VERSION::STRING >= '6.0'
+              original_before_teardown.bind(self).call
+            end
             original_after_teardown.bind(self).call
           ensure
             myio = $stdout
