@@ -43,16 +43,13 @@ module RSpec
 
         included do
           include ::Rails.application.routes.url_helpers
-
-          if ::Rails.application.routes.respond_to?(:mounted_helpers)
-            include ::Rails.application.routes.mounted_helpers
-          end
+          include ::Rails.application.routes.mounted_helpers
         end
 
         # @overload render
-        # @overload render({:partial => path_to_file})
-        # @overload render({:partial => path_to_file}, {... locals ...})
-        # @overload render({:partial => path_to_file}, {... locals ...}) do ... end
+        # @overload render({partial: path_to_file})
+        # @overload render({partial: path_to_file}, {... locals ...})
+        # @overload render({partial: path_to_file}, {... locals ...}) do ... end
         #
         # Delegates to ActionView::Base#render, so see documentation on that
         # for more info.
@@ -62,7 +59,7 @@ module RSpec
         #
         #     describe "widgets/new.html.erb" do
         #       it "shows all the widgets" do
-        #         render # => view.render(:file => "widgets/new.html.erb")
+        #         render # => view.render(file: "widgets/new.html.erb")
         #         # ...
         #       end
         #     end
@@ -105,7 +102,7 @@ module RSpec
 
         # @deprecated Use `view` instead.
         def template
-          RSpec.deprecate("template", :replacement => "view")
+          RSpec.deprecate("template", replacement: "view")
           view
         end
 
@@ -128,20 +125,37 @@ module RSpec
       private
 
         def _default_render_options
-          if ::Rails::VERSION::STRING >= '3.2'
-            # pluck the handler, format, and locale out of, eg, posts/index.de.html.haml
-            template, *components   = _default_file_to_render.split('.')
-            handler, format, locale = *components.reverse
+          formats = if ActionView::Template::Types.respond_to?(:symbols)
+                      ActionView::Template::Types.symbols
+                    else
+                      [:html, :text, :js, :css, :xml, :json].map(&:to_s)
+                    end.map { |x| Regexp.escape(x) }.join("|")
 
-            render_options = { :template => template }
-            render_options[:handlers] = [handler] if handler
-            render_options[:formats] = [format.to_sym] if format
-            render_options[:locales] = [locale] if locale
+          handlers = ActionView::Template::Handlers.extensions.map { |x| Regexp.escape(x) }.join("|")
+          locales = "[a-z]{2}(?:-[A-Z]{2})?"
+          variants = "[^.]*"
+          path_regex = %r{
+          \A
+          (?<template>.*?)
+          (?:\.(?<locale>#{locales}))??
+            (?:\.(?<format>#{formats}))??
+            (?:\+(?<variant>#{variants}))??
+            (?:\.(?<handler>#{handlers}))?
+            \z
+          }x
 
-            render_options
-          else
-            { :template => _default_file_to_render }
-          end
+          # This regex should always find a match.
+          # Worst case, everything will be nil, and :template will just be
+          # the original string.
+          match = path_regex.match(_default_file_to_render)
+
+          render_options = {template: match[:template]}
+          render_options[:handlers] = [match[:handler]] if match[:handler]
+          render_options[:formats] = [match[:format].to_sym] if match[:format]
+          render_options[:locales] = [match[:locale]] if match[:locale]
+          render_options[:variants] = [match[:variant]] if match[:variant]
+
+          render_options
         end
 
         def _path_parts
@@ -171,10 +185,7 @@ module RSpec
 
         before do
           _include_controller_helpers
-          if view.lookup_context.respond_to?(:prefixes)
-            # rails 3.1
-            view.lookup_context.prefixes << _controller_path
-          end
+          view.lookup_context.prefixes << _controller_path
 
           controller.controller_path = _controller_path
 
