@@ -1,4 +1,3 @@
-require "spec_helper"
 require 'rspec/support/spec/in_sub_process'
 
 RSpec.describe "Configuration" do
@@ -59,11 +58,11 @@ RSpec.describe "Configuration" do
   context "adds settings" do
     include_examples "adds setting",
                      :infer_base_class_for_anonymous_controllers,
-                     :default => true
+                     default: true
 
     include_examples "adds setting",
                      :use_transactional_fixtures,
-                     :alias_with => :use_transactional_examples
+                     alias_with: :use_transactional_examples
 
     include_examples "adds setting", :use_instantiated_fixtures
 
@@ -131,7 +130,7 @@ RSpec.describe "Configuration" do
             "./#{location}/foos_spec.rb"
           )
           group = RSpec.describe("Arbitrary Description")
-          expect(group.metadata).to include(:type => type)
+          expect(group.metadata).to include(type: type)
         end
       end
     end
@@ -167,17 +166,17 @@ RSpec.describe "Configuration" do
     a_controller_class = Class.new
     stub_const "SomeController", a_controller_class
 
-    group = RSpec.describe(SomeController, :type => :controller)
+    group = RSpec.describe(SomeController, type: :controller)
 
     expect(group.controller_class).to be(a_controller_class)
     expect(group.new).to be_a(RSpec::Rails::ControllerExampleGroup)
   end
 
-  it "metadata `:type => :helper` sets up helper example groups" do
+  it "metadata `type: :helper` sets up helper example groups" do
     a_helper_module = Module.new
     stub_const "SomeHelper", a_helper_module
 
-    group = RSpec.describe(SomeHelper, :type => :helper)
+    group = RSpec.describe(SomeHelper, type: :helper)
 
     expect(
       group.determine_default_helper_class(:ignored)
@@ -185,58 +184,64 @@ RSpec.describe "Configuration" do
     expect(group.new).to be_a(RSpec::Rails::HelperExampleGroup)
   end
 
-  it "metadata `:type => :model` sets up model example groups" do
+  it "metadata `type: :model` sets up model example groups" do
     a_model_class = Class.new
     stub_const "SomeModel", a_model_class
 
-    group = RSpec.describe(SomeModel, :type => :model)
+    group = RSpec.describe(SomeModel, type: :model)
 
     expect(group.new).to be_a(RSpec::Rails::ModelExampleGroup)
   end
 
-  it "metadata `:type => :request` sets up request example groups" do
+  it "metadata `type: :request` sets up request example groups" do
     a_rails_app = double("Rails application")
-    the_rails_module = Module.new
+    the_rails_module = Module.new {
+      def self.version; end
+      def self.application; end
+    }
     allow(the_rails_module).to receive(:application) { a_rails_app }
     version = ::Rails::VERSION
     stub_const "Rails", the_rails_module
     stub_const 'Rails::VERSION', version
 
-    group = RSpec.describe("Some Request API", :type => :request)
+    group = RSpec.describe("Some Request API", type: :request)
 
     expect(group.new.app).to be(a_rails_app)
     expect(group.new).to be_a(RSpec::Rails::RequestExampleGroup)
   end
 
-  it "metadata `:type => :routing` sets up routing example groups" do
+  it "metadata `type: :routing` sets up routing example groups" do
     a_controller_class = Class.new
     stub_const "SomeController", a_controller_class
 
-    group = RSpec.describe(SomeController, :type => :routing)
+    group = RSpec.describe(SomeController, type: :routing)
 
     expect(group).to respond_to(:routes)
     expect(group.new).to be_a(RSpec::Rails::RoutingExampleGroup)
   end
 
-  it "metadata `:type => :view` sets up view example groups" do
+  it "metadata `type: :view` sets up view example groups" do
     a_helper_module = Module.new
     stub_const "SomeControllerHelper", a_helper_module
 
-    group = RSpec.describe("some_controller/action.html.erb", :type => :view)
+    group = RSpec.describe("some_controller/action.html.erb", type: :view)
 
     expect(group._default_helper).to be(a_helper_module)
     expect(group.new).to be_a(RSpec::Rails::ViewExampleGroup)
   end
 
-  it "metadata `:type => :feature` sets up feature example groups" do
+  it "metadata `type: :feature` sets up feature example groups" do
     a_rails_app = double("Rails application")
-    the_rails_module = Module.new
+    the_rails_module = Module.new {
+      def self.version; end
+      def self.application; end
+    }
     allow(the_rails_module).to receive(:application) { a_rails_app }
     version = ::Rails::VERSION
     stub_const "Rails", the_rails_module
     stub_const 'Rails::VERSION', version
 
-    group = RSpec.describe("Some feature description", :type => :feature)
+    group = RSpec.describe("Some feature description", type: :feature)
     example = group.new
 
     expect(example).to respond_to(:visit)
@@ -244,18 +249,44 @@ RSpec.describe "Configuration" do
   end
 
   if defined?(ActionMailer)
-    it "metadata `:type => :mailer` sets up mailer example groups" do
+    it "metadata `type: :mailer` sets up mailer example groups" do
       a_mailer_class = Class.new
       stub_const "SomeMailer", a_mailer_class
-      group = RSpec.describe(SomeMailer, :type => :mailer)
+      group = RSpec.describe(SomeMailer, type: :mailer)
       expect(group.mailer_class).to be(a_mailer_class)
       expect(group.new).to be_a(RSpec::Rails::MailerExampleGroup)
     end
-  end
 
-  if ::Rails::VERSION::STRING > '5'
-    it "has a default #file_fixture_path of 'spec/fixtures/files'" do
-      expect(config.file_fixture_path).to eq("spec/fixtures/files")
+    describe 'clears ActionMailer::Base::Deliveries after each example' do
+      let(:mailer) do
+        Class.new(ActionMailer::Base) do
+          default from: 'from@example.com'
+
+          def welcome(to:)
+            mail(to: to, subject: 'subject', body: render(inline: "Hello", layout: false))
+          end
+        end
+      end
+
+      before do
+        ActionMailer::Base.delivery_method = :test
+      end
+
+      it 'only has deliveries from this test (e.g. from email@example.com)' do
+        mailer.welcome(to: 'email@example.com').deliver_now
+
+        expect(ActionMailer::Base.deliveries.map(&:to).flatten.sort).to eq(['email@example.com'])
+      end
+
+      it 'only has deliveries from this test (e.g. from email_2@example.com)' do
+        mailer.welcome(to: 'email_2@example.com').deliver_now
+
+        expect(ActionMailer::Base.deliveries.map(&:to).flatten.sort).to eq(['email_2@example.com'])
+      end
     end
   end
+
+  it "has a default #file_fixture_path of 'spec/fixtures/files'" do
+    expect(config.file_fixture_path).to eq("spec/fixtures/files")
+  end
 end
