@@ -1,13 +1,11 @@
-require "spec_helper"
-
 class ::ApplicationController
   def self.abstract?; false; end
 end
 
 module RSpec::Rails
-  describe ControllerExampleGroup do
+  RSpec.describe ControllerExampleGroup do
     it_behaves_like "an rspec-rails example group mixin", :controller,
-      './spec/controllers/', '.\\spec\\controllers\\'
+                    './spec/controllers/', '.\\spec\\controllers\\'
 
     def group_for(klass)
       RSpec::Core::ExampleGroup.describe klass do
@@ -25,7 +23,7 @@ module RSpec::Rails
       it "uses the controller as the subject" do
         controller = double('controller')
         example = group.new
-        allow(example).to receive_messages(:controller => controller)
+        allow(example).to receive_messages(controller: controller)
         expect(example.subject).to eq(controller)
       end
 
@@ -62,12 +60,11 @@ module RSpec::Rails
       let(:controller) { double('controller') }
       let(:example) { group.new }
       let(:routes) do
-        routes = nil
         with_isolated_stderr do
           routes = ActionDispatch::Routing::RouteSet.new
           routes.draw { resources :foos }
+          routes
         end
-        routes
       end
 
       before do
@@ -76,7 +73,7 @@ module RSpec::Rails
         end
 
         allow(controller).to receive(:foos_url).and_return('http://test.host/foos')
-        allow(example).to receive_messages(:controller => controller)
+        allow(example).to receive_messages(controller: controller)
         example.instance_variable_set(:@orig_routes, routes)
       end
 
@@ -84,20 +81,10 @@ module RSpec::Rails
         expect(example.foos_url).to eq('http://test.host/foos')
       end
 
-      if Rails.version.to_f >= 4.2
-        it "calls NamedRouteCollection#route_defined? when it checks that given route is defined or not" do
-          expect(routes.named_routes).to receive(:route_defined?).and_return(true)
-          expect(routes.named_routes).not_to receive(:helpers)
+      it "calls NamedRouteCollection#route_defined? when it checks that given route is defined or not" do
+        expect(routes.named_routes).to receive(:route_defined?).and_return(true)
 
-          example.foos_url
-        end
-      else
-        it "calls NamedRouteCollection#helpers#include? when it checks that given route is defined or not" do
-          expect(routes.named_routes).to \
-            receive_message_chain(:helpers, :include?).with(:foos_url).and_return(true)
-
-          example.foos_url
-        end
+        example.foos_url
       end
     end
 
