@@ -1,7 +1,6 @@
-require "spec_helper"
 require 'rspec/rails/matchers/be_valid'
 
-describe "be_valid matcher" do
+RSpec.describe "be_valid matcher" do
   class Post
     include ActiveModel::Validations
     attr_accessor :title
@@ -24,9 +23,19 @@ describe "be_valid matcher" do
     end
   end
 
+  class Car
+    def valid?
+      false
+    end
+
+    def errors(_)
+    end
+  end
+
   let(:post) { Post.new }
   let(:book) { Book.new }
   let(:boat) { Boat.new }
+  let(:car) { Car.new }
 
   it "includes the error messages in the failure message" do
     expect {
@@ -46,6 +55,12 @@ describe "be_valid matcher" do
     }.to raise_exception(/expected .+ to be valid\z/)
   end
 
+  it "includes a brief error message when error message is wrong arity" do
+    expect {
+      expect(car).to be_valid
+    }.to raise_exception(/expected .+ to be valid\z/)
+  end
+
   it "includes a failure message for the negative case" do
     allow(post).to receive(:valid?) { true }
     expect {
