@@ -1,11 +1,18 @@
-require 'spec_helper'
 require 'pathname'
 
 RSpec.describe "Verify required rspec dependencies" do
 
   tmp_root = Pathname.new(RSpec::Core::RubyProject.root).join("tmp")
 
-  before{ FileUtils.mkdir_p tmp_root }
+  before { FileUtils.mkdir_p tmp_root }
+
+  def with_clean_env
+    if Bundler.respond_to?(:with_unbundled_env)
+      Bundler.with_unbundled_env { yield }
+    else
+      Bundler.with_clean_env { yield }
+    end
+  end
 
   it "fails when libraries are not required" do
     script = tmp_root.join("fail_sanity_check")
@@ -17,16 +24,16 @@ RSpec.describe "Verify required rspec dependencies" do
     end
     FileUtils.chmod 0777, script
 
-    Bundler.with_clean_env do
-      expect(`bundle exec #{script} 2>&1`).
-        to match(/uninitialized constant RSpec::Support/).
-        or match(/undefined method `require_rspec_core' for RSpec::Support:Module/)
+    with_clean_env do
+      expect(`bundle exec #{script} 2>&1`)
+        .to match(/uninitialized constant RSpec::Support/)
+        .or match(/undefined method `require_rspec_core' for RSpec::Support:Module/)
 
       expect($?.exitstatus).to eq(1)
     end
   end
 
-  it "passes when libraries are required" do
+  it "passes when libraries are required", unless: RSpec::Support::Ruby.jruby? do
     script = tmp_root.join("pass_sanity_check")
     File.open(script, "w") do |f|
       f.write <<-EOF.gsub(/^\s+\|/, '')
@@ -38,7 +45,7 @@ RSpec.describe "Verify required rspec dependencies" do
     end
     FileUtils.chmod 0777, script
 
-    Bundler.with_clean_env do
+    with_clean_env do
       expect(`bundle exec #{script} 2>&1`).to be_empty
       expect($?.exitstatus).to eq(0)
     end
